// MicrosoftWord script version 1.0

using LoginPI.Engine.ScriptBase;

public class MicrosoftWord : ScriptBase
{
    private void Execute()
    {   
        // This is a language dependent script. English is required.
    
        //Define environementvariables to use with Workload
        var temp = GetEnvironmentVariable("TEMP");
        RegImport(create_regfile(@"HKEY_CURRENT_USER\Software\Microsoft\Office\16.0\Common\General",@"ShownFirstRunOptin",@"dword:00000001"));

        // Download file from the appliance through the KnownFiles method, if it already exists: Skip Download.
        if(!(FileExists($"{temp}\\LoginPI\\loginvsi.docx")))
        {
            Log("Downloading File");
            CopyFile(KnownFiles.WordDocument, $"{temp}\\LoginPI\\loginvsi.docx");
        }
        else
        {
            Log("File already exists");
        }

        //Start Application
        START();
        Wait(1);

        //Open "Open File" window and start measurement.
        MainWindow.Type("{ESC}");
        Wait(1);
        MainWindow.Type("{CTRL+O}");
        MainWindow.Type("{ALT+O+O}");
        StartTimer("Open_Window");
        var OpenWindow = FindWindow(title : "Open");
        OpenWindow.FindControl(className : "SplitButton:Button", title : "&Open").Click();
        StopTimer("Open_Window");

        //Navigate to copied DOCX file and press Open, measure time to open the file.
        OpenWindow.FindControl(className : "Edit:Edit", title : "File name:").Click();
        Wait(1);
        OpenWindow.Type($"{temp}\\LoginPI\\loginvsi.docx",cpm:300);
        Wait(1);
        OpenWindow.FindControl(className : "SplitButton:Button", title : "&Open").Click();
        StartTimer("Open_Word_Document");
        var newWord = FindWindow(className : "Win32 Window:OpusApp", title: "loginvsi*" ,processName : "WINWORD");
        newWord.Focus();
        newWord.FindControl(className : "TabItem:NetUIRibbonTab", title : "Insert");
        StopTimer("Open_Word_Document");

        //Scroll through Word Document
        newWord.MoveMouseToCenter();
        MouseDown();
        Wait(1);
        MouseUp();
        newWord.Type("{PAGEDOWN}".Repeat(8));
        Wait(1);
        newWord.Type("{PAGEUP}".Repeat(8));

        //Type in the document
        newWord.Type("{CTRL+END}");
        newWord.Type("Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.",cpm : 600);
        Wait(1);

        newWord.Type("{ENTER}");
        newWord.Type("Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.",cpm : 600);

        // Saving the file in temp
        newWord.Type("{F12}",cpm:0);
        Wait(1);
        
        // Remove file if it already exists
        if(FileExists($"{temp}\\LoginPI\\loginvsi_edited.docx"))
        {
            Log("Removing file");
            RemoveFile(path:$"{temp}\\LoginPI\\loginvsi_edited.docx");
        }
        else
        {
            Log("File already removed");
        }       

        // Saving the file in temp 
        MainWindow.Type("{ALT+F+A}");
        var SaveAs = FindWindow(title:"Save As");
        SaveAs.Type($"%temp%\\LoginPI\\loginvsi_edited.docx",cpm:300);
        StartTimer("Saving_file");
        SaveAs.Type("{ENTER}");
        FindWindow(title: "loginvsi_edited*");
        StopTimer("Saving_file");
        Wait(2);


        // Stop application
        Wait(2);
        STOP();

    }
    private string create_regfile(string key, string value, string data)
    {            
        System.Text.StringBuilder sb = new System.Text.StringBuilder();
        var file = System.IO.Path.Combine(System.IO.Path.GetTempPath(), "reg.reg");

        sb.AppendLine("Windows Registry Editor Version 5.00");
        sb.AppendLine();
        sb.AppendLine($"[{key}]");
        if(data.ToLower().Contains("dword"))
        {
            sb.AppendLine($"\"{value}\"={data.ToLower()}");
        }
        else
        {
            sb.AppendLine($"\"{value}\"=\"{data}\"");
        }
        sb.AppendLine();

        System.IO.File.WriteAllText(file, sb.ToString());

        return file;
    }
}